==> ourmon-2.5_1.tbz: mrourmon/src/ourmon/filter.h <==
/* per filter structure
*/

#ifndef IP_FILTER
#define IP_FILTER

#ifndef TRUE
#define TRUE	1
#endif
#ifndef FALSE
#define FALSE	0
#endif

#ifndef IPCOUNTER
#define IPCOUNTER	1
typedef unsigned long COUNTER;
#endif

/* each filter data definition element has
 * #include, counter structure, configured variable
 */

#define FIXED_IPPROTO 1
struct fixed_ipproto {
	int	 configured;
	COUNTER  tcp_bytes;
	COUNTER  udp_bytes;
	COUNTER  icmp_bytes;
	COUNTER  xtra_bytes;
};
extern struct fixed_ipproto fixed_ipproto;

#define FIXED_TCP3   2
struct fixed_tcp3 {
	int configured;
	unsigned short tcp_port1;
	unsigned short tcp_port2;
	COUNTER  port1_bytes;
	COUNTER  port2_bytes;
	COUNTER  xtra_bytes;
};
extern struct fixed_tcp3 fixed_tcp3;

#define FIXED_IPRANGE1	3
struct fixed_iprange1 {
	int configured;
	struct in_addr ipaddr1;
	struct in_addr ipnet1;
	char s_ipnet1[1024];
	struct in_addr netmask1;
	struct in_addr ipaddr2;
	struct in_addr ipnet2;
	char s_ipnet2[1024];
	struct in_addr netmask2;
	COUNTER	 range1_bytes;
	COUNTER  extra_bytes;
};
extern struct fixed_iprange1 fixed_iprange1;

#define FIXED_L2PROTO  4
struct fixed_l2proto {
	int	 configured;
	COUNTER  ip;
	COUNTER  ipv6;
	COUNTER  arp;
	COUNTER  xtra_bytes;	/* not one of the above 3 */
};
extern struct fixed_l2proto fixed_l2proto;

#define FIXED_CAST  5
struct fixed_cast {
	int	 configured;
	struct in_addr ipaddr1;  /* input, anded with netmask */
	struct in_addr netmask1;
	struct in_addr ipnet1;   /* computed all 1's bcast */
	struct in_addr ipnet0;   /* computed all 0's bcast */
	COUNTER  mcast_bytes;
	COUNTER  ucast_bytes;
	COUNTER  bcast_bytes;
	COUNTER  xtra_bytes;
};
extern struct fixed_cast fixed_cast;

#define FIXED_SIZE  6
struct fixed_size {
	int	 configured;
	COUNTER  tiny;
	COUNTER  small;
	COUNTER  medium;
	COUNTER  large;
};
extern struct fixed_size fixed_size;

/* bpf group filter spec:
 * logical structure:
 * name: there may be up to MAXBPF bpf invocations;
 *	i.e., this string is both a label for the whole thing and must be unique
 *	per use.
 * string1 - string4, there may be four bpf filters per graph,
 *	not all must be used.  Each must have its own label,
 *	followed by the bpf program in quotes.
 *
 * config form:
 * bpf uber-label label bpf-expression
 * bpf-next label bpf-expression
 *
 * mon.lite form:
 * bpf: name: #bpfs: label: count: label: count ... xtra: count
 */

#define MAXBPFSPECS	100	/* max. number of labels for all bpf graphs */
#define MAXBPFS		6	/* per bpf specs */
#define MAXLABEL 70    /* max chars in label */
#define MAXBPFLABEL 70    /* max chars in bpf label - too big?*/
/* values of progkind field
*/
#define BPFFREE		0
#define BPFBPF		1		/* stupid but oh well */
#define BPFCPROG	2
#define MAXPORTPAIRS	20
struct bpf_cparams {
	int ipproto;		/* ip protocol */
	int ipprotoflag;	/* needed as ipproto can be 0 */
	struct in_addr netmask;
	struct in_addr net;
	int icmpflag;
	int icmp_major, icmp_minor;
	int tportcount;		/* number of tcp ports */
	int tports[MAXPORTPAIRS];
	int uportcount;		/* number of tcp ports */
	int uports[MAXPORTPAIRS];
	int synflag, finflag, resetflag;	/* tcp control pkt flags */
};
struct bpf_spec {
	char label[MAXLABEL+1];
	int prog_count;		/* number of bpf programs */ 
	struct bpf_program fcodes[MAXBPFS];	/* max bpfs per bpf spec */
	char prog_label[MAXBPFS][MAXBPFLABEL+1];  /* per program label */
	COUNTER bpf_counts[MAXBPFS];  /* per bpf counter */
	COUNTER xtra_bytes;	      /* no bpf match count */
	int configured;
	int noxtra;	              /* turn bpf xtra off */	
	int bpfpackets;		      /* if on count packets, not bytes */
	int progkind[MAXBPFS];	      /* 0 - free, 1 - bpf, 2 - C function */
	struct bpf_cparams cps[MAXBPFS]; /* params to c prog functions */
	/* match = (*bpf->c_program[MAXBPFS])(params);  
	*/
	int (*c_program[MAXBPFS])
	(struct t_entry *, struct bpf_cparams *);   
};
extern struct bpf_spec bpf_spec;

/************************************************** 
 * TOPN
 **************************************************/

#define MAXTOPN		100	/* hard topN maximum. can't have more */

#include "hashsort.h"

#define TOPN_IP	    20
struct topn_ip {
	int configured;
	int actualn;		/* specified value of topN < MAXTOPN */
	struct list iplist;	/* ip dst top N link structure */
};
extern struct topn_ip topn_ip;


#include "hashport.h"

#define MAXTOPPORTS	100	/* topN maximum. can't have more */

struct topn_port {
	int configured;
	int actualn;		/* specified value of topN < MAXTOPPORTS */ 
	struct plist tcplist;	/* tcp port top N link structure */
	struct plist udplist;	/* udp port top N link structure */
};
extern struct topn_port topn_port;



#include "hashscan.h"

struct topn_sip {
	int configured;
	int actualn;		/* specified value of topN < MAXTOPN */
	struct slist iplist;	/* ip dst top N link structure */
};

extern struct topn_sip topn_scans_input;
extern struct topn_sip topn_scans_output;
extern struct hashStats topn_scans_ip_stats;

extern struct topn_sip topn_scans_ports_input;
extern struct topn_sip topn_scans_ports_output;
extern struct hashStats topn_scans_ports_stats;

extern struct topn_sip topn_scans_ports_tcp_input;
extern struct topn_sip topn_scans_ports_tcp_output;
extern struct hashStats topn_scans_ports_tcp_stats;

extern struct topn_sip topn_scans_ports_udp_input;
extern struct topn_sip topn_scans_ports_udp_output;
extern struct hashStats topn_scans_ports_udp_stats;

extern char sysname[];
extern char pktname[];
extern int  pktnameflag;
#define MAXSYSNAME 1025

#include "hashicmp.h"

struct topn_icmperror {
	int configured;
	int actualn;		/* specified value of topN < MAXTOPN */
	struct icmplist icmplist;	/* top N link structure */
};
extern struct topn_icmperror topn_icmperror;

#include "hashsyn.h"

struct topn_syn {
	int configured;
	int sortbysyn;		/* sort by syn, else 100% first */
	int weight;		/* pre-filter for tworm */
	int wormdiff;		/* syns - fins > wormdiff create tcpworm.txt */
	struct in_addr ipaddr;    /* input, anded with netmask */
	struct in_addr netmask;
	char wormfile[1024];    /* basename + tcpworm.txt */
	int wflag;		/* wormfile actually set */
	char p2pfile[1024];     /* basename + p2pfile.txt */
	int p2pflag;		/* wormfile actually set */
	int ipaflag;		/* ipaddr/netmask actually set */
	int actualn;		/* specified value of topN < MAXTOPN */
	struct synlist synlist;	/* top N link structure */
};
extern struct topn_syn topn_syn;

#include "ircscan.h"

struct topn_irc {
	int configured;
	int maxcount;
	int fileflag;
	char ircfile[1024];    /* basename + irc.txt */
	struct irclist irclist;
}; 
extern struct topn_irc topn_irc;

#endif

==> ourmon-2.8.1_3.tbz: mrourmon/src/ourmon/filter.h <==
/* per filter structure
*/

#ifndef IP_FILTER
#define IP_FILTER

#ifndef TRUE
#define TRUE	1
#endif
#ifndef FALSE
#define FALSE	0
#endif

#ifndef IPCOUNTER
#define IPCOUNTER	1
typedef unsigned int COUNTER;
#endif

/* each filter data definition element has
 * #include, counter structure, configured variable
 */

#define FIXED_IPPROTO 1
struct fixed_ipproto {
	int	 configured;
	COUNTER  tcp_bytes;
	COUNTER  udp_bytes;
	COUNTER  icmp_bytes;
	COUNTER  xtra_bytes;
};
extern struct fixed_ipproto fixed_ipproto;

struct fixed_honeynet {
	int	 configured;
	struct in_addr netaddr;
	struct in_addr netmask;
};
extern struct fixed_honeynet fixed_honeynet;
extern struct fixed_honeynet fixed_darknet;

#define FIXED_TCP3   2
struct fixed_tcp3 {
	int configured;
	unsigned short tcp_port1;
	unsigned short tcp_port2;
	COUNTER  port1_bytes;
	COUNTER  port2_bytes;
	COUNTER  xtra_bytes;
};
extern struct fixed_tcp3 fixed_tcp3;

#define FIXED_IPRANGE1	3
struct fixed_iprange1 {
	int configured;
	struct in_addr ipaddr1;
	struct in_addr ipnet1;
	char s_ipnet1[1024];
	struct in_addr netmask1;
	struct in_addr ipaddr2;
	struct in_addr ipnet2;
	char s_ipnet2[1024];
	struct in_addr netmask2;
	COUNTER	 range1_bytes;
	COUNTER  extra_bytes;
};
extern struct fixed_iprange1 fixed_iprange1;

#define FIXED_L2PROTO  4
struct fixed_l2proto {
	int	 configured;
	COUNTER  ip;
	COUNTER  ipv6;
	COUNTER  arp;
	COUNTER  xtra_bytes;	/* not one of the above 3 */
};
extern struct fixed_l2proto fixed_l2proto;

#define FIXED_CAST  5
struct fixed_cast {
	int	 configured;
	struct in_addr ipaddr1;  /* input, anded with netmask */
	struct in_addr netmask1;
	struct in_addr ipnet1;   /* computed all 1's bcast */
	struct in_addr ipnet0;   /* computed all 0's bcast */
	COUNTER  mcast_bytes;
	COUNTER  ucast_bytes;
	COUNTER  bcast_bytes;
	COUNTER  xtra_bytes;
};
extern struct fixed_cast fixed_cast;

#define FIXED_SIZE  6
struct fixed_size {
	int	 configured;
	COUNTER  tiny;
	COUNTER  small;
	COUNTER  medium;
	COUNTER  large;
};
extern struct fixed_size fixed_size;

/* bpf group filter spec:
 * logical structure:
 * name: there may be up to MAXBPF bpf invocations;
 *	i.e., this string is both a label for the whole thing and must be unique
 *	per use.
 * string1 - string4, there may be four bpf filters per graph,
 *	not all must be used.  Each must have its own label,
 *	followed by the bpf program in quotes.
 *
 * config form:
 * bpf uber-label label bpf-expression
 * bpf-next label bpf-expression
 *
 * mon.lite form:
 * bpf: name: #bpfs: label: count: label: count ... xtra: count
 */

#define MAXBPFSPECS	100	/* max. number of labels for all bpf graphs */
#define MAXBPFS		6	/* per bpf specs */
#define MAXLABEL 70    /* max chars in label */
#define MAXBPFLABEL 70    /* max chars in bpf label - too big?*/
/* values of progkind field
*/
#define BPFFREE		0
#define BPFBPF		1		/* stupid but oh well */
#define BPFCPROG	2
#define MAXPORTPAIRS	20
struct bpf_cparams {
	int ipproto;		/* ip protocol */
	int ipprotoflag;	/* needed as ipproto can be 0 */
	struct in_addr netmask;
	struct in_addr net;
	int icmpflag;
	int icmp_major, icmp_minor;
	int tportcount;		/* number of tcp ports */
	int tports[MAXPORTPAIRS];
	int uportcount;		/* number of tcp ports */
	int uports[MAXPORTPAIRS];
	int synflag, finflag, resetflag;	/* tcp control pkt flags */
};
struct bpf_spec {
	char label[MAXLABEL+1];
	int prog_count;		/* number of bpf programs */ 
	struct bpf_program fcodes[MAXBPFS];	/* max bpfs per bpf spec */
	char prog_label[MAXBPFS][MAXBPFLABEL+1];  /* per program label */
	COUNTER bpf_counts[MAXBPFS];  /* per bpf counter */
	COUNTER xtra_bytes;	      /* no bpf match count */
	int configured;
	int noxtra;	              /* turn bpf xtra off */	
	int bpfpackets;		      /* if on count packets, not bytes */
	int progkind[MAXBPFS];	      /* 0 - free, 1 - bpf, 2 - C function */
	struct bpf_cparams cps[MAXBPFS]; /* params to c prog functions */
	/* match = (*bpf->c_program[MAXBPFS])(params);  
	*/
	int (*c_program[MAXBPFS])
	(struct t_entry *, struct bpf_cparams *);   
};
extern struct bpf_spec bpf_spec;

/************************************************** 
 * TOPN
 **************************************************/

#define MAXTOPN		1000 	/* hard topN maximum. can't have more */

#include "hashsort.h"

#define TOPN_IP	    20
struct topn_ip {
	int configured;
	int sflow;		/* smallflow collection on */
	int ssh;		/* ssh scan collection on */
	int actualn;		/* specified value of topN < MAXTOPN */
	char flowfile[1024];    /* flowfile if sflow is TRUE */
	char sshfile[1024];		/* sshfile if ssh is TRUE */
	struct list iplist;		/* ip dst top N link structure */
};
extern struct topn_ip topn_ip;


#include "hashport.h"

struct topn_port {
	int configured;
	int actualn;		/* specified value of topN < MAXTOPN */ 
	struct plist tcplist;	/* tcp port top N link structure */
	struct plist udplist;	/* udp port top N link structure */
};
extern struct topn_port topn_port;



#include "hashscan.h"

struct topn_sip {
	int configured;
	int actualn;		/* specified value of topN < MAXTOPN */
	struct slist iplist;	/* ip dst top N link structure */
};

extern struct topn_sip topn_scans_input;
extern struct topn_sip topn_scans_output;
extern struct hashStats topn_scans_ip_stats;

extern struct topn_sip topn_scans_ports_input;
extern struct topn_sip topn_scans_ports_output;
extern struct hashStats topn_scans_ports_stats;

extern struct topn_sip topn_scans_ports_tcp_input;
extern struct topn_sip topn_scans_ports_tcp_output;
extern struct hashStats topn_scans_ports_tcp_stats;

extern struct topn_sip topn_scans_ports_udp_input;
extern struct topn_sip topn_scans_ports_udp_output;
extern struct hashStats topn_scans_ports_udp_stats;

extern char sysname[];
extern char pktname[];
extern int  pktnameflag;
#define MAXSYSNAME 1025

#include "hashicmp.h"

struct topn_icmperror {
	int configured;
	int actualn;		/* specified value of topN < MAXTOPN */
	struct icmplist icmplist;	/* top N link structure */
};
extern struct topn_icmperror topn_icmperror;

#include "hashsyn.h"

#define MAXHOMEIPS	10

struct topn_syn {
	int configured;
	int sortbysyn;		/* sort by syn, else 100% first */
	int weight;		/* pre-filter for tworm */
	int wormdiff;		/* syns - fins > wormdiff create tcpworm.txt */
	int ipaflag;		/* true if any ipaddr/netmask actually set */
	int homeips;          	/* number of home ip addresses */
	struct in_addr ipaddr[MAXHOMEIPS];    /* input, anded with netmask */
	struct in_addr netmask[MAXHOMEIPS];
	char ipmask[MAXHOMEIPS][512];
	char wormfile[1024];    /* basename + tcpworm.txt */
	int wflag;		/* wormfile actually set */
	char p2pfile[1024];     /* basename + p2pfile.txt */
	int p2pflag;		/* wormfile actually set */
	char syndump[1024];     /* basename + syndump.txt */
	int syndump_flag;	/* syndump file flag actually set */
	char emaildump[1024];   /* basename + emaildump.txt */
	int emailflag;		/* email file flag actually set */
	char potdump[1024];     /* basename + potdump.txt */
	int potflag;		/* pot file flag actually set */
	int actualn;		/* specified value of topN < MAXTOPN */
	struct synlist synlist;	/* top N link structure */
};
extern struct topn_syn topn_syn;

#include "ircscan.h"

struct topn_irc {
	int configured;
	int maxcount;
	int fileflag;
	char ircfile[1024];    /* basename + irc.txt */
	struct irclist irclist;
}; 
extern struct topn_irc topn_irc;

#ifdef SCANMESH
/*****************
 * IPMESH
 *****************/

#include "scanmesh.h"

struct scanmesh {
	/* configured ww thresholds: */
    	int configured;
    	char ipmeshfile[1024];  /* the file where this info gets dumped */
	struct ipmeshlist ipmeshlist;
};
extern struct scanmesh scanmesh;
#endif

#endif
